'''This is nester module and it provides a function called print_lol. 
It prints every elements in list'''

def print_lol(the_list,level):
    '''this is function that print list'''
    #mee too
    for each_item in the_list:
        if isinstance(each_item,list):
            print_lol(each_item,level+1)
        else:
            for tab_stop in range(level):
                print('\t',end='')
            print(each_item)
